@@ -1,22 +1,19 @@
 """Top-level package for PyCMTensor."""
 
 __author__ = """Melvin Wong"""
-__version__ = "1.1.0"
-
-from .logger import main_logger
-
-log = main_logger.log
-
-from .config import Config
-
-config = Config()
+__version__ = "1.2.0"
 
 import numpy as np
 
-from .data import Data
+from .config import Config
+from .logger import *
 
+config = Config()
 rng = np.random.default_rng(config["seed"])
+
 print(
     f"Python {config.info['python_version'].split(' |')[0]}",
     f"| PyCMTensor {__version__}",
 )
+
+from .data import *
